@@ -2,32 +2,37 @@ from pandas.core.arrays.base import (
     ExtensionArray,
     ExtensionOpsMixin,
     ExtensionScalarOpsMixin,
-    try_cast_to_ea,
 )
 from pandas.core.arrays.boolean import BooleanArray
 from pandas.core.arrays.categorical import Categorical
 from pandas.core.arrays.datetimes import DatetimeArray
-from pandas.core.arrays.integer import IntegerArray, integer_array
+from pandas.core.arrays.floating import FloatingArray
+from pandas.core.arrays.integer import IntegerArray
 from pandas.core.arrays.interval import IntervalArray
-from pandas.core.arrays.numpy_ import PandasArray, PandasDtype
-from pandas.core.arrays.period import PeriodArray, period_array
+from pandas.core.arrays.masked import BaseMaskedArray
+from pandas.core.arrays.numpy_ import PandasArray
+from pandas.core.arrays.period import (
+    PeriodArray,
+    period_array,
+)
 from pandas.core.arrays.sparse import SparseArray
 from pandas.core.arrays.string_ import StringArray
+from pandas.core.arrays.string_arrow import ArrowStringArray
 from pandas.core.arrays.timedeltas import TimedeltaArray
 
 __all__ = [
     "ExtensionArray",
     "ExtensionOpsMixin",
     "ExtensionScalarOpsMixin",
-    "try_cast_to_ea",
+    "ArrowStringArray",
+    "BaseMaskedArray",
     "BooleanArray",
     "Categorical",
     "DatetimeArray",
+    "FloatingArray",
     "IntegerArray",
-    "integer_array",
     "IntervalArray",
     "PandasArray",
-    "PandasDtype",
     "PeriodArray",
     "period_array",
     "SparseArray",
