@@ -1,5 +1,7 @@
+from __future__ import annotations
+
 from pathlib import Path
-from typing import Optional, Sequence, Union
+from typing import Sequence
 
 from pandas.compat._optional import import_optional_dependency
 
@@ -7,10 +9,12 @@ from pandas.core.dtypes.inference import is_list_like
 
 from pandas.core.api import DataFrame
 
+from pandas.io.common import stringify_path
+
 
 def read_spss(
-    path: Union[str, Path],
-    usecols: Optional[Sequence[str]] = None,
+    path: str | Path,
+    usecols: Sequence[str] | None = None,
     convert_categoricals: bool = True,
 ) -> DataFrame:
     """
@@ -40,6 +44,6 @@ def read_spss(
             usecols = list(usecols)  # pyreadstat requires a list
 
     df, _ = pyreadstat.read_sav(
-        path, usecols=usecols, apply_value_formats=convert_categoricals
+        stringify_path(path), usecols=usecols, apply_value_formats=convert_categoricals
     )
     return df
