@@ -1,17 +1,35 @@
+from __future__ import annotations
+
 import decimal
 import numbers
 import random
 import sys
-from typing import Type
 
 import numpy as np
 
+from pandas._typing import type_t
+
 from pandas.core.dtypes.base import ExtensionDtype
-from pandas.core.dtypes.common import pandas_dtype
+from pandas.core.dtypes.common import (
+    is_dtype_equal,
+    is_float,
+    pandas_dtype,
+)
 
 import pandas as pd
-from pandas.api.extensions import no_default, register_extension_dtype
-from pandas.core.arrays import ExtensionArray, ExtensionScalarOpsMixin
+from pandas.api.extensions import (
+    no_default,
+    register_extension_dtype,
+)
+from pandas.api.types import (
+    is_list_like,
+    is_scalar,
+)
+from pandas.core.arraylike import OpsMixin
+from pandas.core.arrays import (
+    ExtensionArray,
+    ExtensionScalarOpsMixin,
+)
 from pandas.core.indexers import check_array_indexer
 
 
@@ -29,7 +47,7 @@ class DecimalDtype(ExtensionDtype):
         return f"DecimalDtype(context={self.context})"
 
     @classmethod
-    def construct_array_type(cls) -> Type["DecimalArray"]:
+    def construct_array_type(cls) -> type_t[DecimalArray]:
         """
         Return the array type associated with this dtype.
 
@@ -44,12 +62,14 @@ class DecimalDtype(ExtensionDtype):
         return True
 
 
-class DecimalArray(ExtensionArray, ExtensionScalarOpsMixin):
+class DecimalArray(OpsMixin, ExtensionScalarOpsMixin, ExtensionArray):
     __array_priority__ = 1000
 
     def __init__(self, values, dtype=None, copy=False, context=None):
-        for val in values:
-            if not isinstance(val, decimal.Decimal):
+        for i, val in enumerate(values):
+            if is_float(val) and np.isnan(val):
+                values[i] = DecimalDtype.na_value
+            elif not isinstance(val, decimal.Decimal):
                 raise TypeError("All values must be of type " + str(decimal.Decimal))
         values = np.asarray(values, dtype=object)
 
@@ -88,7 +108,7 @@ class DecimalArray(ExtensionArray, ExtensionScalarOpsMixin):
             result = np.asarray([round(x, decimals) for x in result])
         return result
 
-    def __array_ufunc__(self, ufunc, method, *inputs, **kwargs):
+    def __array_ufunc__(self, ufunc: np.ufunc, method: str, *inputs, **kwargs):
         #
         if not all(
             isinstance(t, self._HANDLED_TYPES + (DecimalArray,)) for t in inputs
@@ -128,18 +148,21 @@ class DecimalArray(ExtensionArray, ExtensionScalarOpsMixin):
         return self._from_sequence(result)
 
     def copy(self):
-        return type(self)(self._data.copy())
+        return type(self)(self._data.copy(), dtype=self.dtype)
 
     def astype(self, dtype, copy=True):
+        if is_dtype_equal(dtype, self._dtype):
+            if not copy:
+                return self
         dtype = pandas_dtype(dtype)
         if isinstance(dtype, type(self.dtype)):
-            return type(self)(self._data, context=dtype.context)
+            return type(self)(self._data, copy=copy, context=dtype.context)
 
         return super().astype(dtype, copy=copy)
 
     def __setitem__(self, key, value):
-        if pd.api.types.is_list_like(value):
-            if pd.api.types.is_scalar(key):
+        if is_list_like(value):
+            if is_scalar(key):
                 raise ValueError("setting an array element with a sequence.")
             value = [decimal.Decimal(v) for v in value]
         else:
@@ -151,6 +174,14 @@ class DecimalArray(ExtensionArray, ExtensionScalarOpsMixin):
     def __len__(self) -> int:
         return len(self._data)
 
+    def __contains__(self, item) -> bool | np.bool_:
+        if not isinstance(item, decimal.Decimal):
+            return False
+        elif item.is_nan():
+            return self.isna().any()
+        else:
+            return super().__contains__(item)
+
     @property
     def nbytes(self) -> int:
         n = len(self)
@@ -167,14 +198,14 @@ class DecimalArray(ExtensionArray, ExtensionScalarOpsMixin):
 
     def _formatter(self, boxed=False):
         if boxed:
-            return "Decimal: {0}".format
+            return "Decimal: {}".format
         return repr
 
     @classmethod
     def _concat_same_type(cls, to_concat):
         return cls(np.concatenate([x._data for x in to_concat]))
 
-    def _reduce(self, name: str, skipna: bool = True, **kwargs):
+    def _reduce(self, name: str, *, skipna: bool = True, **kwargs):
 
         if skipna:
             # If we don't have any NAs, we can ignore skipna
@@ -194,6 +225,30 @@ class DecimalArray(ExtensionArray, ExtensionScalarOpsMixin):
             ) from err
         return op(axis=0)
 
+    def _cmp_method(self, other, op):
+        # For use with OpsMixin
+        def convert_values(param):
+            if isinstance(param, ExtensionArray) or is_list_like(param):
+                ovalues = param
+            else:
+                # Assume it's an object
+                ovalues = [param] * len(self)
+            return ovalues
+
+        lvalues = self
+        rvalues = convert_values(other)
+
+        # If the operator is not defined for the underlying objects,
+        # a TypeError should be raised
+        res = [op(a, b) for (a, b) in zip(lvalues, rvalues)]
+
+        return np.asarray(res, dtype=bool)
+
+    def value_counts(self, dropna: bool = True):
+        from pandas.core.algorithms import value_counts
+
+        return value_counts(self.to_numpy(), dropna=dropna)
+
 
 def to_decimal(values, context=None):
     return DecimalArray([decimal.Decimal(x) for x in values], context=context)
@@ -204,4 +259,3 @@ def make_data():
 
 
 DecimalArray._add_arithmetic_ops()
-DecimalArray._add_comparison_ops()
