@@ -3,7 +3,11 @@ from itertools import product
 import numpy as np
 import pytest
 
-from pandas import DataFrame, NaT, date_range
+from pandas import (
+    DataFrame,
+    NaT,
+    date_range,
+)
 import pandas._testing as tm
 
 
@@ -76,6 +80,11 @@ def bool_frame_with_na():
     # set some NAs
     df.iloc[5:10] = np.nan
     df.iloc[15:20, -2:] = np.nan
+
+    # For `any` tests we need to have at least one True before the first NaN
+    #  in each column
+    for i in range(4):
+        df.iloc[i, i] = True
     return df
 
 
@@ -178,24 +187,6 @@ def mixed_int_frame():
     return df
 
 
-@pytest.fixture
-def mixed_type_frame():
-    """
-    Fixture for DataFrame of float/int/string columns with RangeIndex
-    Columns are ['a', 'b', 'c', 'float32', 'int32'].
-    """
-    return DataFrame(
-        {
-            "a": 1.0,
-            "b": 2,
-            "c": "foo",
-            "float32": np.array([1.0] * 10, dtype="float32"),
-            "int32": np.array([1] * 10, dtype="int32"),
-        },
-        index=np.arange(10),
-    )
-
-
 @pytest.fixture
 def timezone_frame():
     """
