@@ -1,11 +1,13 @@
+from __future__ import annotations
+
+from datetime import datetime
 import gc
-from typing import Type
 
 import numpy as np
 import pytest
 
 from pandas._libs import iNaT
-from pandas.errors import InvalidIndexError
+from pandas._libs.tslibs import Timestamp
 
 from pandas.core.dtypes.common import is_datetime64tz_dtype
 from pandas.core.dtypes.dtypes import CategoricalDtype
@@ -14,6 +16,7 @@ import pandas as pd
 from pandas import (
     CategoricalIndex,
     DatetimeIndex,
+    Float64Index,
     Index,
     Int64Index,
     IntervalIndex,
@@ -30,29 +33,40 @@ from pandas.core.indexes.datetimelike import DatetimeIndexOpsMixin
 
 
 class Base:
-    """ base class for index sub-class tests """
+    """
+    Base class for index sub-class tests.
+    """
 
-    _holder: Type[Index]
-    _compat_props = ["shape", "ndim", "size", "nbytes"]
+    _index_cls: type[Index]
+
+    @pytest.fixture
+    def simple_index(self):
+        raise NotImplementedError("Method not implemented")
 
     def create_index(self) -> Index:
         raise NotImplementedError("Method not implemented")
 
     def test_pickle_compat_construction(self):
         # need an object to create with
-        msg = (
-            r"Index\(\.\.\.\) must be called with a collection of some "
-            r"kind, None was passed|"
-            r"__new__\(\) missing 1 required positional argument: 'data'|"
-            r"__new__\(\) takes at least 2 arguments \(1 given\)"
+        msg = "|".join(
+            [
+                r"Index\(\.\.\.\) must be called with a collection of some "
+                r"kind, None was passed",
+                r"DatetimeIndex\(\) must be called with a collection of some "
+                r"kind, None was passed",
+                r"TimedeltaIndex\(\) must be called with a collection of some "
+                r"kind, None was passed",
+                r"__new__\(\) missing 1 required positional argument: 'data'",
+                r"__new__\(\) takes at least 2 arguments \(1 given\)",
+            ]
         )
         with pytest.raises(TypeError, match=msg):
-            self._holder()
+            self._index_cls()
 
     @pytest.mark.parametrize("name", [None, "new_name"])
-    def test_to_frame(self, name):
+    def test_to_frame(self, name, simple_index):
         # see GH-15230, GH-22580
-        idx = self.create_index()
+        idx = simple_index
 
         if name:
             idx_name = name
@@ -69,39 +83,42 @@ class Base:
         df = idx.to_frame(index=False, name=idx_name)
         assert df.index is not idx
 
-    def test_shift(self):
+    def test_shift(self, simple_index):
 
         # GH8083 test the base class for shift
-        idx = self.create_index()
-        msg = f"Not supported for type {type(idx).__name__}"
+        idx = simple_index
+        msg = (
+            f"This method is only implemented for DatetimeIndex, PeriodIndex and "
+            f"TimedeltaIndex; Got type {type(idx).__name__}"
+        )
         with pytest.raises(NotImplementedError, match=msg):
             idx.shift(1)
         with pytest.raises(NotImplementedError, match=msg):
             idx.shift(1, 2)
 
-    def test_constructor_name_unhashable(self):
+    def test_constructor_name_unhashable(self, simple_index):
         # GH#29069 check that name is hashable
         # See also same-named test in tests.series.test_constructors
-        idx = self.create_index()
+        idx = simple_index
         with pytest.raises(TypeError, match="Index.name must be a hashable type"):
             type(idx)(idx, name=[])
 
-    def test_create_index_existing_name(self):
+    def test_create_index_existing_name(self, simple_index):
 
         # GH11193, when an existing index is passed, and a new name is not
         # specified, the new index should inherit the previous object name
-        expected = self.create_index()
+        expected = simple_index
         if not isinstance(expected, MultiIndex):
             expected.name = "foo"
-            result = pd.Index(expected)
+            result = Index(expected)
             tm.assert_index_equal(result, expected)
 
-            result = pd.Index(expected, name="bar")
+            result = Index(expected, name="bar")
             expected.name = "bar"
             tm.assert_index_equal(result, expected)
         else:
             expected.names = ["foo", "bar"]
-            result = pd.Index(expected)
+            result = Index(expected)
             tm.assert_index_equal(
                 result,
                 Index(
@@ -120,7 +137,7 @@ class Base:
                 ),
             )
 
-            result = pd.Index(expected, names=["A", "B"])
+            result = Index(expected, names=["A", "B"])
             tm.assert_index_equal(
                 result,
                 Index(
@@ -139,86 +156,64 @@ class Base:
                 ),
             )
 
-    def test_numeric_compat(self):
+    def test_numeric_compat(self, simple_index):
 
-        idx = self.create_index()
+        idx = simple_index
         # Check that this doesn't cover MultiIndex case, if/when it does,
         #  we can remove multi.test_compat.test_numeric_compat
         assert not isinstance(idx, MultiIndex)
+        if type(idx) is Index:
+            return
 
-        with pytest.raises(TypeError, match="cannot perform __mul__"):
+        typ = type(idx._data).__name__
+        lmsg = "|".join(
+            [
+                rf"unsupported operand type\(s\) for \*: '{typ}' and 'int'",
+                "cannot perform (__mul__|__truediv__|__floordiv__) with "
+                f"this index type: {typ}",
+            ]
+        )
+        with pytest.raises(TypeError, match=lmsg):
             idx * 1
-        with pytest.raises(TypeError, match="cannot perform __rmul__"):
+        rmsg = "|".join(
+            [
+                rf"unsupported operand type\(s\) for \*: 'int' and '{typ}'",
+                "cannot perform (__rmul__|__rtruediv__|__rfloordiv__) with "
+                f"this index type: {typ}",
+            ]
+        )
+        with pytest.raises(TypeError, match=rmsg):
             1 * idx
 
-        div_err = "cannot perform __truediv__"
+        div_err = lmsg.replace("*", "/")
         with pytest.raises(TypeError, match=div_err):
             idx / 1
-
-        div_err = div_err.replace(" __", " __r")
+        div_err = rmsg.replace("*", "/")
         with pytest.raises(TypeError, match=div_err):
             1 / idx
-        with pytest.raises(TypeError, match="cannot perform __floordiv__"):
+
+        floordiv_err = lmsg.replace("*", "//")
+        with pytest.raises(TypeError, match=floordiv_err):
             idx // 1
-        with pytest.raises(TypeError, match="cannot perform __rfloordiv__"):
+        floordiv_err = rmsg.replace("*", "//")
+        with pytest.raises(TypeError, match=floordiv_err):
             1 // idx
 
-    def test_logical_compat(self):
-        idx = self.create_index()
+    def test_logical_compat(self, simple_index):
+        idx = simple_index
         with pytest.raises(TypeError, match="cannot perform all"):
             idx.all()
         with pytest.raises(TypeError, match="cannot perform any"):
             idx.any()
 
-    def test_reindex_base(self):
-        idx = self.create_index()
-        expected = np.arange(idx.size, dtype=np.intp)
+    def test_repr_roundtrip(self, simple_index):
 
-        actual = idx.get_indexer(idx)
-        tm.assert_numpy_array_equal(expected, actual)
-
-        with pytest.raises(ValueError, match="Invalid fill method"):
-            idx.get_indexer(idx, method="invalid")
-
-    def test_get_indexer_consistency(self, index):
-        # See GH 16819
-        if isinstance(index, IntervalIndex):
-            return
-
-        if index.is_unique or isinstance(index, CategoricalIndex):
-            indexer = index.get_indexer(index[0:2])
-            assert isinstance(indexer, np.ndarray)
-            assert indexer.dtype == np.intp
-        else:
-            e = "Reindexing only valid with uniquely valued Index objects"
-            with pytest.raises(InvalidIndexError, match=e):
-                index.get_indexer(index[0:2])
-
-        indexer, _ = index.get_indexer_non_unique(index[0:2])
-        assert isinstance(indexer, np.ndarray)
-        assert indexer.dtype == np.intp
-
-    def test_ndarray_compat_properties(self):
-        idx = self.create_index()
-        assert idx.T.equals(idx)
-        assert idx.transpose().equals(idx)
-
-        values = idx.values
-        for prop in self._compat_props:
-            assert getattr(idx, prop) == getattr(values, prop)
-
-        # test for validity
-        idx.nbytes
-        idx.values.nbytes
-
-    def test_repr_roundtrip(self):
-
-        idx = self.create_index()
+        idx = simple_index
         tm.assert_index_equal(eval(repr(idx)), idx)
 
-    def test_repr_max_seq_item_setting(self):
+    def test_repr_max_seq_item_setting(self, simple_index):
         # GH10182
-        idx = self.create_index()
+        idx = simple_index
         idx = idx.repeat(50)
         with pd.option_context("display.max_seq_items", None):
             repr(idx)
@@ -250,6 +245,20 @@ class Base:
             s3 = s1 * s2
             assert s3.index.name == "mario"
 
+    def test_copy_name2(self, index):
+        # gh-35592
+        if isinstance(index, MultiIndex):
+            return
+
+        assert index.copy(name="mario").name == "mario"
+
+        with pytest.raises(ValueError, match="Length of new names must be 1, got 2"):
+            index.copy(name=["mario", "luigi"])
+
+        msg = f"{type(index).__name__}.name must be a hashable type"
+        with pytest.raises(TypeError, match=msg):
+            index.copy(name=[["mario"]])
+
     def test_ensure_copied_data(self, index):
         # Check the "copy" argument of each Index.__new__ is honoured
         # GH12309
@@ -325,6 +334,7 @@ class Base:
         # cannot be changed at the moment due to
         # backwards compatibility concerns
         if isinstance(type(index), (CategoricalIndex, RangeIndex)):
+            # TODO: why type(index)?
             msg = "the 'axis' parameter is not supported"
             with pytest.raises(ValueError, match=msg):
                 np.argsort(index, axis=1)
@@ -337,183 +347,44 @@ class Base:
             with pytest.raises(ValueError, match=msg):
                 np.argsort(index, order=("a", "b"))
 
-    def test_take(self, index):
-        indexer = [4, 3, 0, 2]
-        if len(index) < 5:
-            # not enough elements; ignore
-            return
-
-        result = index.take(indexer)
-        expected = index[indexer]
-        assert result.equals(expected)
-
-        if not isinstance(index, (DatetimeIndex, PeriodIndex, TimedeltaIndex)):
-            # GH 10791
-            msg = r"'(.*Index)' object has no attribute 'freq'"
-            with pytest.raises(AttributeError, match=msg):
-                index.freq
-
-    def test_take_invalid_kwargs(self):
-        idx = self.create_index()
-        indices = [1, 2]
-
-        msg = r"take\(\) got an unexpected keyword argument 'foo'"
-        with pytest.raises(TypeError, match=msg):
-            idx.take(indices, foo=2)
-
-        msg = "the 'out' parameter is not supported"
-        with pytest.raises(ValueError, match=msg):
-            idx.take(indices, out=indices)
-
-        msg = "the 'mode' parameter is not supported"
-        with pytest.raises(ValueError, match=msg):
-            idx.take(indices, mode="clip")
-
-    def test_repeat(self):
+    def test_repeat(self, simple_index):
         rep = 2
-        i = self.create_index()
-        expected = pd.Index(i.values.repeat(rep), name=i.name)
-        tm.assert_index_equal(i.repeat(rep), expected)
+        idx = simple_index.copy()
+        expected = Index(idx.values.repeat(rep), name=idx.name)
+        tm.assert_index_equal(idx.repeat(rep), expected)
 
-        i = self.create_index()
-        rep = np.arange(len(i))
-        expected = pd.Index(i.values.repeat(rep), name=i.name)
-        tm.assert_index_equal(i.repeat(rep), expected)
+        idx = simple_index
+        rep = np.arange(len(idx))
+        expected = Index(idx.values.repeat(rep), name=idx.name)
+        tm.assert_index_equal(idx.repeat(rep), expected)
 
-    def test_numpy_repeat(self):
+    def test_numpy_repeat(self, simple_index):
         rep = 2
-        i = self.create_index()
-        expected = i.repeat(rep)
-        tm.assert_index_equal(np.repeat(i, rep), expected)
+        idx = simple_index
+        expected = idx.repeat(rep)
+        tm.assert_index_equal(np.repeat(idx, rep), expected)
 
         msg = "the 'axis' parameter is not supported"
         with pytest.raises(ValueError, match=msg):
-            np.repeat(i, rep, axis=0)
+            np.repeat(idx, rep, axis=0)
 
     @pytest.mark.parametrize("klass", [list, tuple, np.array, Series])
-    def test_where(self, klass):
-        i = self.create_index()
-        if isinstance(i, (pd.DatetimeIndex, pd.TimedeltaIndex)):
+    def test_where(self, klass, simple_index):
+        idx = simple_index
+        if isinstance(idx, (DatetimeIndex, TimedeltaIndex)):
             # where does not preserve freq
-            i = i._with_freq(None)
+            idx = idx._with_freq(None)
 
-        cond = [True] * len(i)
-        result = i.where(klass(cond))
-        expected = i
+        cond = [True] * len(idx)
+        result = idx.where(klass(cond))
+        expected = idx
         tm.assert_index_equal(result, expected)
 
-        cond = [False] + [True] * len(i[1:])
-        expected = pd.Index([i._na_value] + i[1:].tolist(), dtype=i.dtype)
-        result = i.where(klass(cond))
+        cond = [False] + [True] * len(idx[1:])
+        expected = Index([idx._na_value] + idx[1:].tolist(), dtype=idx.dtype)
+        result = idx.where(klass(cond))
         tm.assert_index_equal(result, expected)
 
-    @pytest.mark.parametrize("case", [0.5, "xxx"])
-    @pytest.mark.parametrize(
-        "method", ["intersection", "union", "difference", "symmetric_difference"]
-    )
-    def test_set_ops_error_cases(self, case, method, index):
-        # non-iterable input
-        msg = "Input must be Index or array-like"
-        with pytest.raises(TypeError, match=msg):
-            getattr(index, method)(case)
-
-    def test_intersection_base(self, index):
-        if isinstance(index, CategoricalIndex):
-            return
-
-        first = index[:5]
-        second = index[:3]
-        intersect = first.intersection(second)
-        assert tm.equalContents(intersect, second)
-
-        if is_datetime64tz_dtype(index.dtype):
-            # The second.values below will drop tz, so the rest of this test
-            #  is not applicable.
-            return
-
-        # GH 10149
-        cases = [klass(second.values) for klass in [np.array, Series, list]]
-        for case in cases:
-            result = first.intersection(case)
-            assert tm.equalContents(result, second)
-
-        if isinstance(index, MultiIndex):
-            msg = "other must be a MultiIndex or a list of tuples"
-            with pytest.raises(TypeError, match=msg):
-                first.intersection([1, 2, 3])
-
-    def test_union_base(self, index):
-        first = index[3:]
-        second = index[:5]
-        everything = index
-        union = first.union(second)
-        assert tm.equalContents(union, everything)
-
-        if is_datetime64tz_dtype(index.dtype):
-            # The second.values below will drop tz, so the rest of this test
-            #  is not applicable.
-            return
-
-        # GH 10149
-        cases = [klass(second.values) for klass in [np.array, Series, list]]
-        for case in cases:
-            if not isinstance(index, CategoricalIndex):
-                result = first.union(case)
-                assert tm.equalContents(result, everything)
-
-        if isinstance(index, MultiIndex):
-            msg = "other must be a MultiIndex or a list of tuples"
-            with pytest.raises(TypeError, match=msg):
-                first.union([1, 2, 3])
-
-    def test_difference_base(self, sort, index):
-        first = index[2:]
-        second = index[:4]
-        if isinstance(index, CategoricalIndex) or index.is_boolean():
-            answer = []
-        else:
-            answer = index[4:]
-        result = first.difference(second, sort)
-        assert tm.equalContents(result, answer)
-
-        # GH 10149
-        cases = [klass(second.values) for klass in [np.array, Series, list]]
-        for case in cases:
-            if isinstance(index, (DatetimeIndex, TimedeltaIndex)):
-                assert type(result) == type(answer)
-                tm.assert_numpy_array_equal(
-                    result.sort_values().asi8, answer.sort_values().asi8
-                )
-            else:
-                result = first.difference(case, sort)
-                assert tm.equalContents(result, answer)
-
-        if isinstance(index, MultiIndex):
-            msg = "other must be a MultiIndex or a list of tuples"
-            with pytest.raises(TypeError, match=msg):
-                first.difference([1, 2, 3], sort)
-
-    def test_symmetric_difference(self, index):
-        if isinstance(index, CategoricalIndex):
-            return
-
-        first = index[1:]
-        second = index[:-1]
-        answer = index[[0, -1]]
-        result = first.symmetric_difference(second)
-        assert tm.equalContents(result, answer)
-
-        # GH 10149
-        cases = [klass(second.values) for klass in [np.array, Series, list]]
-        for case in cases:
-            result = first.symmetric_difference(case)
-            assert tm.equalContents(result, answer)
-
-        if isinstance(index, MultiIndex):
-            msg = "other must be a MultiIndex or a list of tuples"
-            with pytest.raises(TypeError, match=msg):
-                first.symmetric_difference([1, 2, 3])
-
     def test_insert_base(self, index):
         result = index[1:4]
 
@@ -548,7 +419,8 @@ class Base:
 
     def test_equals(self, index):
         if isinstance(index, IntervalIndex):
-            # IntervalIndex tested separately
+            # IntervalIndex tested separately, the index.equals(index.astype(object))
+            #  fails for IntervalIndex
             return
 
         assert index.equals(index)
@@ -568,11 +440,9 @@ class Base:
             # do not test MultiIndex
             assert not index.equals(Series(index))
 
-    def test_equals_op(self):
+    def test_equals_op(self, simple_index):
         # GH9947, GH10637
-        index_a = self.create_index()
-        if isinstance(index_a, PeriodIndex):
-            pytest.skip("Skip check for PeriodIndex")
+        index_a = simple_index
 
         n = len(index_a)
         index_b = index_a[0:-1]
@@ -630,24 +500,24 @@ class Base:
             # assuming the 2nd to last item is unique in the data
             item = index_a[-2]
             tm.assert_numpy_array_equal(index_a == item, expected3)
+            # For RangeIndex we can convert to Int64Index
             tm.assert_series_equal(series_a == item, Series(expected3))
 
-    def test_format(self):
+    def test_format(self, simple_index):
         # GH35439
-        idx = self.create_index()
+        idx = simple_index
         expected = [str(x) for x in idx]
         assert idx.format() == expected
 
     def test_format_empty(self):
         # GH35712
-        empty_idx = self._holder([])
+        empty_idx = self._index_cls([])
         assert empty_idx.format() == []
         assert empty_idx.format(name=True) == [""]
 
-    def test_hasnans_isnans(self, index):
+    def test_hasnans_isnans(self, index_flat):
         # GH 11343, added tests for hasnans / isnans
-        if isinstance(index, MultiIndex):
-            return
+        index = index_flat
 
         # cases in indices doesn't include NaN
         idx = index.copy(deep=True)
@@ -662,7 +532,7 @@ class Base:
             return
         elif isinstance(index, DatetimeIndexOpsMixin):
             values[1] = iNaT
-        elif isinstance(index, (Int64Index, UInt64Index)):
+        elif isinstance(index, (Int64Index, UInt64Index, RangeIndex)):
             return
         else:
             values[1] = np.nan
@@ -701,7 +571,7 @@ class Base:
 
             if isinstance(index, DatetimeIndexOpsMixin):
                 values[1] = iNaT
-            elif isinstance(index, (Int64Index, UInt64Index)):
+            elif isinstance(index, (Int64Index, UInt64Index, RangeIndex)):
                 return
             else:
                 values[1] = np.nan
@@ -734,111 +604,99 @@ class Base:
             tm.assert_numpy_array_equal(index.isna(), result)
             tm.assert_numpy_array_equal(index.notna(), ~result)
 
-    def test_empty(self):
+    def test_empty(self, simple_index):
         # GH 15270
-        index = self.create_index()
-        assert not index.empty
-        assert index[:0].empty
+        idx = simple_index
+        assert not idx.empty
+        assert idx[:0].empty
 
-    def test_join_self_unique(self, join_type):
-        index = self.create_index()
-        if index.is_unique:
-            joined = index.join(index, how=join_type)
-            assert (index == joined).all()
+    def test_join_self_unique(self, join_type, simple_index):
+        idx = simple_index
+        if idx.is_unique:
+            joined = idx.join(idx, how=join_type)
+            assert (idx == joined).all()
 
-    def test_map(self):
+    def test_map(self, simple_index):
         # callable
-        index = self.create_index()
+        idx = simple_index
 
         # we don't infer UInt64
-        if isinstance(index, pd.UInt64Index):
-            expected = index.astype("int64")
+        if isinstance(idx, UInt64Index):
+            expected = idx.astype("int64")
         else:
-            expected = index
+            expected = idx
 
-        result = index.map(lambda x: x)
+        result = idx.map(lambda x: x)
+        # For RangeIndex we convert to Int64Index
         tm.assert_index_equal(result, expected)
 
     @pytest.mark.parametrize(
         "mapper",
         [
             lambda values, index: {i: e for e, i in zip(values, index)},
-            lambda values, index: pd.Series(values, index),
+            lambda values, index: Series(values, index),
         ],
     )
-    def test_map_dictlike(self, mapper):
+    def test_map_dictlike(self, mapper, simple_index):
 
-        index = self.create_index()
-        if isinstance(index, (pd.CategoricalIndex, pd.IntervalIndex)):
-            pytest.skip(f"skipping tests for {type(index)}")
+        idx = simple_index
+        if isinstance(idx, CategoricalIndex):
+            pytest.skip(f"skipping tests for {type(idx)}")
 
-        identity = mapper(index.values, index)
+        identity = mapper(idx.values, idx)
 
         # we don't infer to UInt64 for a dict
-        if isinstance(index, pd.UInt64Index) and isinstance(identity, dict):
-            expected = index.astype("int64")
+        if isinstance(idx, UInt64Index) and isinstance(identity, dict):
+            expected = idx.astype("int64")
         else:
-            expected = index
+            expected = idx
 
-        result = index.map(identity)
+        result = idx.map(identity)
+        # For RangeIndex we convert to Int64Index
         tm.assert_index_equal(result, expected)
 
         # empty mappable
-        expected = pd.Index([np.nan] * len(index))
-        result = index.map(mapper(expected, index))
+        expected = Index([np.nan] * len(idx))
+        result = idx.map(mapper(expected, idx))
         tm.assert_index_equal(result, expected)
 
-    def test_map_str(self):
+    def test_map_str(self, simple_index):
         # GH 31202
-        index = self.create_index()
-        result = index.map(str)
-        expected = Index([str(x) for x in index], dtype=object)
+        idx = simple_index
+        result = idx.map(str)
+        expected = Index([str(x) for x in idx], dtype=object)
         tm.assert_index_equal(result, expected)
 
-    def test_putmask_with_wrong_mask(self):
-        # GH18368
-        index = self.create_index()
-
-        msg = "putmask: mask and data must be the same size"
-        with pytest.raises(ValueError, match=msg):
-            index.putmask(np.ones(len(index) + 1, np.bool_), 1)
-
-        with pytest.raises(ValueError, match=msg):
-            index.putmask(np.ones(len(index) - 1, np.bool_), 1)
-
-        with pytest.raises(ValueError, match=msg):
-            index.putmask("foo", 1)
-
     @pytest.mark.parametrize("copy", [True, False])
     @pytest.mark.parametrize("name", [None, "foo"])
     @pytest.mark.parametrize("ordered", [True, False])
-    def test_astype_category(self, copy, name, ordered):
+    def test_astype_category(self, copy, name, ordered, simple_index):
         # GH 18630
-        index = self.create_index()
+        idx = simple_index
         if name:
-            index = index.rename(name)
+            idx = idx.rename(name)
 
         # standard categories
         dtype = CategoricalDtype(ordered=ordered)
-        result = index.astype(dtype, copy=copy)
-        expected = CategoricalIndex(index.values, name=name, ordered=ordered)
-        tm.assert_index_equal(result, expected)
+        result = idx.astype(dtype, copy=copy)
+        expected = CategoricalIndex(idx, name=name, ordered=ordered)
+        tm.assert_index_equal(result, expected, exact=True)
 
         # non-standard categories
-        dtype = CategoricalDtype(index.unique().tolist()[:-1], ordered)
-        result = index.astype(dtype, copy=copy)
-        expected = CategoricalIndex(index.values, name=name, dtype=dtype)
-        tm.assert_index_equal(result, expected)
+        dtype = CategoricalDtype(idx.unique().tolist()[:-1], ordered)
+        result = idx.astype(dtype, copy=copy)
+        expected = CategoricalIndex(idx, name=name, dtype=dtype)
+        tm.assert_index_equal(result, expected, exact=True)
 
         if ordered is False:
             # dtype='category' defaults to ordered=False, so only test once
-            result = index.astype("category", copy=copy)
-            expected = CategoricalIndex(index.values, name=name)
-            tm.assert_index_equal(result, expected)
+            result = idx.astype("category", copy=copy)
+            expected = CategoricalIndex(idx, name=name)
+            tm.assert_index_equal(result, expected, exact=True)
 
-    def test_is_unique(self):
+    def test_is_unique(self, simple_index):
         # initialize a unique index
-        index = self.create_index().drop_duplicates()
+        index = simple_index.drop_duplicates()
         assert index.is_unique is True
 
         # empty index should be unique
@@ -857,62 +715,143 @@ class Base:
         index_na_dup = index_na.insert(0, np.nan)
         assert index_na_dup.is_unique is False
 
-    def test_engine_reference_cycle(self):
+    @pytest.mark.arm_slow
+    def test_engine_reference_cycle(self, simple_index):
         # GH27585
-        index = self.create_index()
+        index = simple_index
         nrefs_pre = len(gc.get_referrers(index))
         index._engine
         assert len(gc.get_referrers(index)) == nrefs_pre
 
-    def test_getitem_2d_deprecated(self):
+    def test_getitem_2d_deprecated(self, simple_index):
         # GH#30588
-        idx = self.create_index()
-        with tm.assert_produces_warning(FutureWarning, check_stacklevel=False):
+        idx = simple_index
+        msg = "Support for multi-dimensional indexing"
+        check = not isinstance(idx, (RangeIndex, CategoricalIndex))
+        with tm.assert_produces_warning(
+            FutureWarning, match=msg, check_stacklevel=check
+        ):
             res = idx[:, None]
 
         assert isinstance(res, np.ndarray), type(res)
 
-    def test_contains_requires_hashable_raises(self):
-        idx = self.create_index()
-
-        msg = "unhashable type: 'list'"
-        with pytest.raises(TypeError, match=msg):
-            [] in idx
-
-        msg = "|".join(
-            [
-                r"unhashable type: 'dict'",
-                r"must be real number, not dict",
-                r"an integer is required",
-                r"\{\}",
-                r"pandas\._libs\.interval\.IntervalTree' is not iterable",
-            ]
-        )
-        with pytest.raises(TypeError, match=msg):
-            {} in idx._engine
-
-    def test_copy_copies_cache(self):
-        # GH32898
-        idx = self.create_index()
+    def test_copy_shares_cache(self, simple_index):
+        # GH32898, GH36840
+        idx = simple_index
         idx.get_loc(idx[0])  # populates the _cache.
         copy = idx.copy()
 
-        # check that the copied cache is a copy of the original
-        assert idx._cache == copy._cache
-        assert idx._cache is not copy._cache
-        # cache values should reference the same object
-        for key, val in idx._cache.items():
-            assert copy._cache[key] is val, key
+        assert copy._cache is idx._cache
 
-    def test_shallow_copy_copies_cache(self):
-        # GH32669
-        idx = self.create_index()
+    def test_shallow_copy_shares_cache(self, simple_index):
+        # GH32669, GH36840
+        idx = simple_index
         idx.get_loc(idx[0])  # populates the _cache.
-        shallow_copy = idx._shallow_copy()
+        shallow_copy = idx._view()
 
-        # check that the shallow_copied cache is a copy of the original
-        assert idx._cache == shallow_copy._cache
-        assert idx._cache is not shallow_copy._cache
-        # cache values should reference the same object
-        for key, val in idx._cache.items():
-            assert shallow_copy._cache[key] is val, key
+        assert shallow_copy._cache is idx._cache
+
+        shallow_copy = idx._shallow_copy(idx._data)
+        assert shallow_copy._cache is not idx._cache
+        assert shallow_copy._cache == {}
+
+    def test_index_groupby(self, simple_index):
+        idx = simple_index[:5]
+        to_groupby = np.array([1, 2, np.nan, 2, 1])
+        tm.assert_dict_equal(
+            idx.groupby(to_groupby), {1.0: idx[[0, 4]], 2.0: idx[[1, 3]]}
+        )
+
+        to_groupby = DatetimeIndex(
+            [
+                datetime(2011, 11, 1),
+                datetime(2011, 12, 1),
+                pd.NaT,
+                datetime(2011, 12, 1),
+                datetime(2011, 11, 1),
+            ],
+            tz="UTC",
+        ).values
+
+        ex_keys = [Timestamp("2011-11-01"), Timestamp("2011-12-01")]
+        expected = {ex_keys[0]: idx[[0, 4]], ex_keys[1]: idx[[1, 3]]}
+        tm.assert_dict_equal(idx.groupby(to_groupby), expected)
+
+
+class NumericBase(Base):
+    """
+    Base class for numeric index (incl. RangeIndex) sub-class tests.
+    """
+
+    def test_constructor_unwraps_index(self, dtype):
+        idx = Index([1, 2], dtype=dtype)
+        result = self._index_cls(idx)
+        expected = np.array([1, 2], dtype=dtype)
+        tm.assert_numpy_array_equal(result._data, expected)
+
+    def test_where(self):
+        # Tested in numeric.test_indexing
+        pass
+
+    def test_can_hold_identifiers(self, simple_index):
+        idx = simple_index
+        key = idx[0]
+        assert idx._can_hold_identifiers_and_holds_name(key) is False
+
+    def test_format(self, simple_index):
+        # GH35439
+        idx = simple_index
+        max_width = max(len(str(x)) for x in idx)
+        expected = [str(x).ljust(max_width) for x in idx]
+        assert idx.format() == expected
+
+    def test_numeric_compat(self):
+        pass  # override Base method
+
+    def test_insert_na(self, nulls_fixture, simple_index):
+        # GH 18295 (test missing)
+        index = simple_index
+        na_val = nulls_fixture
+
+        if na_val is pd.NaT:
+            expected = Index([index[0], pd.NaT] + list(index[1:]), dtype=object)
+        else:
+            expected = Float64Index([index[0], np.nan] + list(index[1:]))
+
+        result = index.insert(1, na_val)
+        tm.assert_index_equal(result, expected)
+
+    def test_arithmetic_explicit_conversions(self):
+        # GH 8608
+        # add/sub are overridden explicitly for Float/Int Index
+        index_cls = self._index_cls
+        if index_cls is RangeIndex:
+            idx = RangeIndex(5)
+        else:
+            idx = index_cls(np.arange(5, dtype="int64"))
+
+        # float conversions
+        arr = np.arange(5, dtype="int64") * 3.2
+        expected = Float64Index(arr)
+        fidx = idx * 3.2
+        tm.assert_index_equal(fidx, expected)
+        fidx = 3.2 * idx
+        tm.assert_index_equal(fidx, expected)
+
+        # interops with numpy arrays
+        expected = Float64Index(arr)
+        a = np.zeros(5, dtype="float64")
+        result = fidx - a
+        tm.assert_index_equal(result, expected)
+
+        expected = Float64Index(-arr)
+        a = np.zeros(5, dtype="float64")
+        result = a - fidx
+        tm.assert_index_equal(result, expected)
+
+    def test_invalid_dtype(self, invalid_dtype):
+        # GH 29539
+        dtype = invalid_dtype
+        msg = fr"Incorrect `dtype` passed: expected \w+(?: \w+)?, received {dtype}"
+        with pytest.raises(ValueError, match=msg):
+            self._index_cls([1, 2, 3], dtype=dtype)
