@@ -2,11 +2,8 @@ import numpy as np
 import pytest
 
 from pandas._libs.tslibs.period import IncompatibleFrequency
-import pandas.util._test_decorators as td
 
-import pandas as pd
 from pandas import (
-    DataFrame,
     DatetimeIndex,
     Index,
     NaT,
@@ -18,12 +15,15 @@ from pandas import (
     period_range,
 )
 import pandas._testing as tm
-
-from ..datetimelike import DatetimeLike
+from pandas.tests.indexes.datetimelike import DatetimeLike
 
 
 class TestPeriodIndex(DatetimeLike):
-    _holder = PeriodIndex
+    _index_cls = PeriodIndex
+
+    @pytest.fixture
+    def simple_index(self) -> Index:
+        return period_range("20130101", periods=5, freq="D")
 
     @pytest.fixture(
         params=[
@@ -35,11 +35,9 @@ class TestPeriodIndex(DatetimeLike):
     def index(self, request):
         return request.param
 
-    def create_index(self) -> PeriodIndex:
-        return period_range("20130101", periods=5, freq="D")
-
+    @pytest.mark.xfail(reason="Goes through a generate_range path")
     def test_pickle_compat_construction(self):
-        pass
+        super().test_pickle_compat_construction()
 
     @pytest.mark.parametrize("freq", ["D", "M", "A"])
     def test_pickle_round_trip(self, freq):
@@ -51,22 +49,6 @@ class TestPeriodIndex(DatetimeLike):
         # This is handled in test_indexing
         pass
 
-    @pytest.mark.parametrize("use_numpy", [True, False])
-    @pytest.mark.parametrize(
-        "index",
-        [
-            period_range("2000-01-01", periods=3, freq="D"),
-            period_range("2001-01-01", periods=3, freq="2D"),
-            PeriodIndex(["2001-01", "NaT", "2003-01"], freq="M"),
-        ],
-    )
-    def test_repeat_freqstr(self, index, use_numpy):
-        # GH10183
-        expected = PeriodIndex([p for p in index for _ in range(3)])
-        result = np.repeat(index, 3) if use_numpy else index.repeat(3)
-        tm.assert_index_equal(result, expected)
-        assert result.freqstr == index.freqstr
-
     def test_no_millisecond_field(self):
         msg = "type object 'DatetimeIndex' has no attribute 'millisecond'"
         with pytest.raises(AttributeError, match=msg):
@@ -81,25 +63,6 @@ class TestPeriodIndex(DatetimeLike):
         series = Series(1, index=index)
         assert isinstance(series, Series)
 
-    def test_shallow_copy_empty(self):
-        # GH13067
-        idx = PeriodIndex([], freq="M")
-        result = idx._shallow_copy()
-        expected = idx
-
-        tm.assert_index_equal(result, expected)
-
-    def test_shallow_copy_disallow_i8(self):
-        # GH-24391
-        pi = period_range("2018-01-01", periods=3, freq="2D")
-        with pytest.raises(AssertionError, match="ndarray"):
-            pi._shallow_copy(pi.asi8)
-
-    def test_shallow_copy_requires_disallow_period_index(self):
-        pi = period_range("2018-01-01", periods=3, freq="2D")
-        with pytest.raises(AssertionError, match="PeriodIndex"):
-            pi._shallow_copy(pi)
-
     def test_view_asi8(self):
         idx = PeriodIndex([], freq="M")
 
@@ -249,14 +212,16 @@ class TestPeriodIndex(DatetimeLike):
             "weekofyear",
             "week",
             "dayofweek",
+            "day_of_week",
             "dayofyear",
+            "day_of_year",
             "quarter",
             "qyear",
             "days_in_month",
         ]
 
         periods = list(periodindex)
-        s = pd.Series(periodindex)
+        s = Series(periodindex)
 
         for field in fields:
             field_idx = getattr(periodindex, field)
@@ -272,46 +237,6 @@ class TestPeriodIndex(DatetimeLike):
             for x, val in zip(periods, field_s):
                 assert getattr(x, field) == val
 
-    def test_period_set_index_reindex(self):
-        # GH 6631
-        df = DataFrame(np.random.random(6))
-        idx1 = period_range("2011/01/01", periods=6, freq="M")
-        idx2 = period_range("2013", periods=6, freq="A")
-
-        df = df.set_index(idx1)
-        tm.assert_index_equal(df.index, idx1)
-        df = df.set_index(idx2)
-        tm.assert_index_equal(df.index, idx2)
-
-    @pytest.mark.parametrize(
-        "p_values, o_values, values, expected_values",
-        [
-            (
-                [Period("2019Q1", "Q-DEC"), Period("2019Q2", "Q-DEC")],
-                [Period("2019Q1", "Q-DEC"), Period("2019Q2", "Q-DEC"), "All"],
-                [1.0, 1.0],
-                [1.0, 1.0, np.nan],
-            ),
-            (
-                [Period("2019Q1", "Q-DEC"), Period("2019Q2", "Q-DEC")],
-                [Period("2019Q1", "Q-DEC"), Period("2019Q2", "Q-DEC")],
-                [1.0, 1.0],
-                [1.0, 1.0],
-            ),
-        ],
-    )
-    def test_period_reindex_with_object(
-        self, p_values, o_values, values, expected_values
-    ):
-        # GH 28337
-        period_index = PeriodIndex(p_values)
-        object_index = Index(o_values)
-
-        s = pd.Series(values, index=period_index)
-        result = s.reindex(object_index)
-        expected = pd.Series(expected_values, index=object_index)
-        tm.assert_series_equal(result, expected)
-
     def test_is_(self):
         create_index = lambda: period_range(freq="A", start="1/1/2001", end="12/1/2009")
         index = create_index()
@@ -330,14 +255,6 @@ class TestPeriodIndex(DatetimeLike):
         assert not index.is_(index - 2)
         assert not index.is_(index - 0)
 
-    def test_periods_number_check(self):
-        msg = (
-            "Of the three parameters: start, end, and periods, exactly two "
-            "must be specified"
-        )
-        with pytest.raises(ValueError, match=msg):
-            period_range("2011-1-1", "2012-1-1", "B")
-
     def test_index_duplicate_periods(self):
         # monotonic
         idx = PeriodIndex([2000, 2007, 2007, 2009, 2009], freq="A-JUN")
@@ -363,19 +280,10 @@ class TestPeriodIndex(DatetimeLike):
         tm.assert_index_equal(idx.unique(), expected)
         assert idx.nunique() == 3
 
-        idx = PeriodIndex([2000, 2007, 2007, 2009, 2007], freq="A-JUN", tz="US/Eastern")
-        expected = PeriodIndex([2000, 2007, 2009], freq="A-JUN", tz="US/Eastern")
-        tm.assert_index_equal(idx.unique(), expected)
-        assert idx.nunique() == 3
-
     def test_shift(self):
         # This is tested in test_arithmetic
         pass
 
-    @td.skip_if_32bit
-    def test_ndarray_compat_properties(self):
-        super().test_ndarray_compat_properties()
-
     def test_negative_ordinals(self):
         Period(ordinal=-1000, freq="A")
         Period(ordinal=0, freq="A")
@@ -423,25 +331,6 @@ class TestPeriodIndex(DatetimeLike):
         assert isinstance(result[0], Period)
         assert result[0].freq == index.freq
 
-    def test_is_full(self):
-        index = PeriodIndex([2005, 2007, 2009], freq="A")
-        assert not index.is_full
-
-        index = PeriodIndex([2005, 2006, 2007], freq="A")
-        assert index.is_full
-
-        index = PeriodIndex([2005, 2005, 2007], freq="A")
-        assert not index.is_full
-
-        index = PeriodIndex([2005, 2005, 2006], freq="A")
-        assert index.is_full
-
-        index = PeriodIndex([2006, 2005, 2005], freq="A")
-        with pytest.raises(ValueError, match="Index is not monotonic"):
-            index.is_full
-
-        assert index[:0].is_full
-
     def test_with_multi_index(self):
         # #1705
         index = date_range("1/1/2012", periods=4, freq="12H")
@@ -453,29 +342,6 @@ class TestPeriodIndex(DatetimeLike):
 
         assert isinstance(s.index.values[0][0], Period)
 
-    def test_convert_array_of_periods(self):
-        rng = period_range("1/1/2000", periods=20, freq="D")
-        periods = list(rng)
-
-        result = Index(periods)
-        assert isinstance(result, PeriodIndex)
-
-    def test_append_concat(self):
-        # #1815
-        d1 = date_range("12/31/1990", "12/31/1999", freq="A-DEC")
-        d2 = date_range("12/31/2000", "12/31/2009", freq="A-DEC")
-
-        s1 = Series(np.random.randn(10), d1)
-        s2 = Series(np.random.randn(10), d2)
-
-        s1 = s1.to_period()
-        s2 = s2.to_period()
-
-        # drops index
-        result = pd.concat([s1, s2])
-        assert isinstance(result.index, PeriodIndex)
-        assert result.index[0] == s1.index[0]
-
     def test_pickle_freq(self):
         # GH2891
         prng = period_range("1/1/2011", "1/1/2012", freq="M")
@@ -491,50 +357,11 @@ class TestPeriodIndex(DatetimeLike):
         exp = Index([x.ordinal for x in index])
         tm.assert_index_equal(result, exp)
 
-    def test_insert(self):
-        # GH 18295 (test missing)
-        expected = PeriodIndex(["2017Q1", NaT, "2017Q2", "2017Q3", "2017Q4"], freq="Q")
-        for na in (np.nan, NaT, None):
-            result = period_range("2017Q1", periods=4, freq="Q").insert(1, na)
-            tm.assert_index_equal(result, expected)
-
-    @pytest.mark.parametrize(
-        "msg, key",
-        [
-            (r"Period\('2019', 'A-DEC'\), 'foo', 'bar'", (Period(2019), "foo", "bar")),
-            (r"Period\('2019', 'A-DEC'\), 'y1', 'bar'", (Period(2019), "y1", "bar")),
-            (r"Period\('2019', 'A-DEC'\), 'foo', 'z1'", (Period(2019), "foo", "z1")),
-            (
-                r"Period\('2018', 'A-DEC'\), Period\('2016', 'A-DEC'\), 'bar'",
-                (Period(2018), Period(2016), "bar"),
-            ),
-            (r"Period\('2018', 'A-DEC'\), 'foo', 'y1'", (Period(2018), "foo", "y1")),
-            (
-                r"Period\('2017', 'A-DEC'\), 'foo', Period\('2015', 'A-DEC'\)",
-                (Period(2017), "foo", Period(2015)),
-            ),
-            (r"Period\('2017', 'A-DEC'\), 'z1', 'bar'", (Period(2017), "z1", "bar")),
-        ],
-    )
-    def test_contains_raise_error_if_period_index_is_in_multi_index(self, msg, key):
-        # issue 20684
-        """
-        parse_time_string return parameter if type not matched.
-        PeriodIndex.get_loc takes returned value from parse_time_string as a tuple.
-        If first argument is Period and a tuple has 3 items,
-        process go on not raise exception
-        """
-        df = DataFrame(
-            {
-                "A": [Period(2019), "x1", "x2"],
-                "B": [Period(2018), Period(2016), "y1"],
-                "C": [Period(2017), "z1", Period(2015)],
-                "V1": [1, 2, 3],
-                "V2": [10, 20, 30],
-            }
-        ).set_index(["A", "B", "C"])
-        with pytest.raises(KeyError, match=msg):
-            df.loc[key]
+    def test_format_empty(self):
+        # GH35712
+        empty_idx = self._index_cls([], freq="A")
+        assert empty_idx.format() == []
+        assert empty_idx.format(name=True) == [""]
 
 
 def test_maybe_convert_timedelta():
