@@ -5,18 +5,26 @@ from datetime import datetime
 from itertools import chain
 
 import numpy as np
-from numpy.random import randn
 import pytest
 
 import pandas.util._test_decorators as td
 
 import pandas as pd
-from pandas import DataFrame, Series, date_range
+from pandas import (
+    DataFrame,
+    Series,
+    date_range,
+)
 import pandas._testing as tm
-from pandas.tests.plotting.common import TestPlotBase, _check_plot_works
+from pandas.tests.plotting.common import (
+    TestPlotBase,
+    _check_plot_works,
+)
 
 import pandas.plotting as plotting
 
+pytestmark = pytest.mark.slow
+
 
 @td.skip_if_no_mpl
 class TestSeriesPlots(TestPlotBase):
@@ -35,7 +43,6 @@ class TestSeriesPlots(TestPlotBase):
         self.iseries = tm.makePeriodSeries()
         self.iseries.name = "iseries"
 
-    @pytest.mark.slow
     def test_plot(self):
         _check_plot_works(self.ts.plot, label="foo")
         _check_plot_works(self.ts.plot, use_index=False)
@@ -59,7 +66,7 @@ class TestSeriesPlots(TestPlotBase):
             _check_plot_works(self.series[:5].plot, kind=kind)
 
         _check_plot_works(self.series[:10].plot.barh)
-        ax = _check_plot_works(Series(randn(10)).plot.bar, color="black")
+        ax = _check_plot_works(Series(np.random.randn(10)).plot.bar, color="black")
         self._check_colors([ax.patches[0]], facecolors=["black"])
 
         # GH 6951
@@ -71,7 +78,6 @@ class TestSeriesPlots(TestPlotBase):
         ax = _check_plot_works(self.ts.plot, subplots=True, layout=(1, -1))
         self._check_axes_shape(ax, axes_num=1, layout=(1, 1))
 
-    @pytest.mark.slow
     def test_plot_figsize_and_title(self):
         # figsize and title
         _, ax = self.plt.subplots()
@@ -109,6 +115,7 @@ class TestSeriesPlots(TestPlotBase):
         line = ax.get_lines()[0].get_data(orig=False)[0]
         assert xmin <= line[0]
         assert xmax >= line[-1]
+        self._check_ticks_props(ax, xrot=0)
         tm.close()
 
         # GH 7471
@@ -118,6 +125,7 @@ class TestSeriesPlots(TestPlotBase):
         line = ax.get_lines()[0].get_data(orig=False)[0]
         assert xmin <= line[0]
         assert xmax >= line[-1]
+        self._check_ticks_props(ax, xrot=30)
         tm.close()
 
         tz_ts = self.ts.copy()
@@ -128,6 +136,7 @@ class TestSeriesPlots(TestPlotBase):
         line = ax.get_lines()[0].get_data(orig=False)[0]
         assert xmin <= line[0]
         assert xmax >= line[-1]
+        self._check_ticks_props(ax, xrot=0)
         tm.close()
 
         _, ax = self.plt.subplots()
@@ -136,6 +145,17 @@ class TestSeriesPlots(TestPlotBase):
         line = ax.get_lines()[0].get_data(orig=False)[0]
         assert xmin <= line[0]
         assert xmax >= line[-1]
+        self._check_ticks_props(ax, xrot=0)
+
+    def test_area_sharey_dont_overwrite(self):
+        # GH37942
+        fig, (ax1, ax2) = self.plt.subplots(1, 2, sharey=True)
+
+        abs(self.ts).plot(ax=ax1, kind="area")
+        abs(self.ts).plot(ax=ax2, kind="area")
+
+        assert ax1._shared_y_axes.joined(ax1, ax2)
+        assert ax2._shared_y_axes.joined(ax1, ax2)
 
     def test_label(self):
         s = Series([1, 2])
@@ -209,7 +229,6 @@ class TestSeriesPlots(TestPlotBase):
         label2 = ax2.get_xlabel()
         assert label2 == ""
 
-    @pytest.mark.slow
     def test_bar_log(self):
         expected = np.array([1e-1, 1e0, 1e1, 1e2, 1e3, 1e4])
 
@@ -243,7 +262,6 @@ class TestSeriesPlots(TestPlotBase):
         tm.assert_almost_equal(res[1], ymax)
         tm.assert_numpy_array_equal(ax.xaxis.get_ticklocs(), expected)
 
-    @pytest.mark.slow
     def test_bar_ignore_index(self):
         df = Series([1, 2, 3, 4], index=["a", "b", "c", "d"])
         _, ax = self.plt.subplots()
@@ -263,7 +281,7 @@ class TestSeriesPlots(TestPlotBase):
         assert result == expected
 
     def test_rotation(self):
-        df = DataFrame(randn(5, 5))
+        df = DataFrame(np.random.randn(5, 5))
         # Default rot 0
         _, ax = self.plt.subplots()
         axes = df.plot(ax=ax)
@@ -278,12 +296,13 @@ class TestSeriesPlots(TestPlotBase):
 
         rng = date_range("1/1/2000", "3/1/2000")
         rng = rng[[0, 1, 2, 3, 5, 9, 10, 11, 12]]
-        ser = Series(randn(len(rng)), rng)
+        ser = Series(np.random.randn(len(rng)), rng)
         _, ax = self.plt.subplots()
         ax = ser.plot(ax=ax)
         xp = DatetimeConverter.convert(datetime(1999, 1, 1), "", ax)
         ax.set_xlim("1/1/1999", "1/1/2001")
         assert xp == ax.get_xlim()[0]
+        self._check_ticks_props(ax, xrot=30)
 
     def test_unsorted_index_xlim(self):
         ser = Series(
@@ -297,7 +316,6 @@ class TestSeriesPlots(TestPlotBase):
         assert xmin <= np.nanmin(lines[0].get_data(orig=False)[0])
         assert xmax >= np.nanmax(lines[0].get_data(orig=False)[0])
 
-    @pytest.mark.slow
     def test_pie_series(self):
         # if sum of values is less than 1.0, pie handle them as rate and draw
         # semicircle.
@@ -330,15 +348,15 @@ class TestSeriesPlots(TestPlotBase):
         ax = _check_plot_works(
             series.plot.pie, colors=color_args, autopct="%.2f", fontsize=7
         )
-        pcts = [f"{s*100:.2f}" for s in series.values / float(series.sum())]
+        pcts = [f"{s*100:.2f}" for s in series.values / series.sum()]
         expected_texts = list(chain.from_iterable(zip(series.index, pcts)))
         self._check_text_labels(ax.texts, expected_texts)
         for t in ax.texts:
             assert t.get_fontsize() == 7
 
         # includes negative value
-        with pytest.raises(ValueError):
-            series = Series([1, 2, 0, 4, -1], index=["a", "b", "c", "d", "e"])
+        series = Series([1, 2, 0, 4, -1], index=["a", "b", "c", "d", "e"])
+        with pytest.raises(ValueError, match="pie plot doesn't allow negative values"):
             series.plot.pie()
 
         # includes nan
@@ -354,156 +372,6 @@ class TestSeriesPlots(TestPlotBase):
         result = [x.get_text() for x in ax.texts]
         assert result == expected
 
-    @pytest.mark.slow
-    def test_hist_df_kwargs(self):
-        df = DataFrame(np.random.randn(10, 2))
-        _, ax = self.plt.subplots()
-        ax = df.plot.hist(bins=5, ax=ax)
-        assert len(ax.patches) == 10
-
-    @pytest.mark.slow
-    def test_hist_df_with_nonnumerics(self):
-        # GH 9853
-        with tm.RNGContext(1):
-            df = DataFrame(np.random.randn(10, 4), columns=["A", "B", "C", "D"])
-        df["E"] = ["x", "y"] * 5
-        _, ax = self.plt.subplots()
-        ax = df.plot.hist(bins=5, ax=ax)
-        assert len(ax.patches) == 20
-
-        _, ax = self.plt.subplots()
-        ax = df.plot.hist(ax=ax)  # bins=10
-        assert len(ax.patches) == 40
-
-    @pytest.mark.slow
-    def test_hist_legacy(self):
-        _check_plot_works(self.ts.hist)
-        _check_plot_works(self.ts.hist, grid=False)
-        _check_plot_works(self.ts.hist, figsize=(8, 10))
-        # _check_plot_works adds an ax so catch warning. see GH #13188
-        with tm.assert_produces_warning(UserWarning):
-            _check_plot_works(self.ts.hist, by=self.ts.index.month)
-        with tm.assert_produces_warning(UserWarning):
-            _check_plot_works(self.ts.hist, by=self.ts.index.month, bins=5)
-
-        fig, ax = self.plt.subplots(1, 1)
-        _check_plot_works(self.ts.hist, ax=ax)
-        _check_plot_works(self.ts.hist, ax=ax, figure=fig)
-        _check_plot_works(self.ts.hist, figure=fig)
-        tm.close()
-
-        fig, (ax1, ax2) = self.plt.subplots(1, 2)
-        _check_plot_works(self.ts.hist, figure=fig, ax=ax1)
-        _check_plot_works(self.ts.hist, figure=fig, ax=ax2)
-
-        with pytest.raises(ValueError):
-            self.ts.hist(by=self.ts.index, figure=fig)
-
-    @pytest.mark.slow
-    def test_hist_bins_legacy(self):
-        df = DataFrame(np.random.randn(10, 2))
-        ax = df.hist(bins=2)[0][0]
-        assert len(ax.patches) == 2
-
-    @pytest.mark.slow
-    def test_hist_layout(self):
-        df = self.hist_df
-        with pytest.raises(ValueError):
-            df.height.hist(layout=(1, 1))
-
-        with pytest.raises(ValueError):
-            df.height.hist(layout=[1, 1])
-
-    @pytest.mark.slow
-    def test_hist_layout_with_by(self):
-        df = self.hist_df
-
-        # _check_plot_works adds an ax so catch warning. see GH #13188
-        with tm.assert_produces_warning(UserWarning):
-            axes = _check_plot_works(df.height.hist, by=df.gender, layout=(2, 1))
-        self._check_axes_shape(axes, axes_num=2, layout=(2, 1))
-
-        with tm.assert_produces_warning(UserWarning):
-            axes = _check_plot_works(df.height.hist, by=df.gender, layout=(3, -1))
-        self._check_axes_shape(axes, axes_num=2, layout=(3, 1))
-
-        with tm.assert_produces_warning(UserWarning):
-            axes = _check_plot_works(df.height.hist, by=df.category, layout=(4, 1))
-        self._check_axes_shape(axes, axes_num=4, layout=(4, 1))
-
-        with tm.assert_produces_warning(UserWarning):
-            axes = _check_plot_works(df.height.hist, by=df.category, layout=(2, -1))
-        self._check_axes_shape(axes, axes_num=4, layout=(2, 2))
-
-        with tm.assert_produces_warning(UserWarning):
-            axes = _check_plot_works(df.height.hist, by=df.category, layout=(3, -1))
-        self._check_axes_shape(axes, axes_num=4, layout=(3, 2))
-
-        with tm.assert_produces_warning(UserWarning):
-            axes = _check_plot_works(df.height.hist, by=df.category, layout=(-1, 4))
-        self._check_axes_shape(axes, axes_num=4, layout=(1, 4))
-
-        with tm.assert_produces_warning(UserWarning):
-            axes = _check_plot_works(df.height.hist, by=df.classroom, layout=(2, 2))
-        self._check_axes_shape(axes, axes_num=3, layout=(2, 2))
-
-        axes = df.height.hist(by=df.category, layout=(4, 2), figsize=(12, 7))
-        self._check_axes_shape(axes, axes_num=4, layout=(4, 2), figsize=(12, 7))
-
-    @pytest.mark.slow
-    def test_hist_no_overlap(self):
-        from matplotlib.pyplot import gcf, subplot
-
-        x = Series(randn(2))
-        y = Series(randn(2))
-        subplot(121)
-        x.hist()
-        subplot(122)
-        y.hist()
-        fig = gcf()
-        axes = fig.axes
-        assert len(axes) == 2
-
-    @pytest.mark.slow
-    def test_hist_secondary_legend(self):
-        # GH 9610
-        df = DataFrame(np.random.randn(30, 4), columns=list("abcd"))
-
-        # primary -> secondary
-        _, ax = self.plt.subplots()
-        ax = df["a"].plot.hist(legend=True, ax=ax)
-        df["b"].plot.hist(ax=ax, legend=True, secondary_y=True)
-        # both legends are dran on left ax
-        # left and right axis must be visible
-        self._check_legend_labels(ax, labels=["a", "b (right)"])
-        assert ax.get_yaxis().get_visible()
-        assert ax.right_ax.get_yaxis().get_visible()
-        tm.close()
-
-        # secondary -> secondary
-        _, ax = self.plt.subplots()
-        ax = df["a"].plot.hist(legend=True, secondary_y=True, ax=ax)
-        df["b"].plot.hist(ax=ax, legend=True, secondary_y=True)
-        # both legends are draw on left ax
-        # left axis must be invisible, right axis must be visible
-        self._check_legend_labels(ax.left_ax, labels=["a (right)", "b (right)"])
-        assert not ax.left_ax.get_yaxis().get_visible()
-        assert ax.get_yaxis().get_visible()
-        tm.close()
-
-        # secondary -> primary
-        _, ax = self.plt.subplots()
-        ax = df["a"].plot.hist(legend=True, secondary_y=True, ax=ax)
-        # right axes is returned
-        df["b"].plot.hist(ax=ax, legend=True)
-        # both legends are draw on left ax
-        # left and right axis must be visible
-        self._check_legend_labels(ax.left_ax, labels=["a (right)", "b"])
-        assert ax.left_ax.get_yaxis().get_visible()
-        assert ax.get_yaxis().get_visible()
-        tm.close()
-
-    @pytest.mark.slow
     def test_df_series_secondary_legend(self):
         # GH 9779
         df = DataFrame(np.random.randn(30, 3), columns=list("abc"))
@@ -513,7 +381,7 @@ class TestSeriesPlots(TestPlotBase):
         _, ax = self.plt.subplots()
         ax = df.plot(ax=ax)
         s.plot(legend=True, secondary_y=True, ax=ax)
-        # both legends are dran on left ax
+        # both legends are drawn on left ax
         # left and right axis must be visible
         self._check_legend_labels(ax, labels=["a", "b", "c", "x (right)"])
         assert ax.get_yaxis().get_visible()
@@ -524,7 +392,7 @@ class TestSeriesPlots(TestPlotBase):
         _, ax = self.plt.subplots()
         ax = df.plot(ax=ax)
         s.plot(ax=ax, legend=True, secondary_y=True)
-        # both legends are dran on left ax
+        # both legends are drawn on left ax
         # left and right axis must be visible
         self._check_legend_labels(ax, labels=["a", "b", "c", "x (right)"])
         assert ax.get_yaxis().get_visible()
@@ -535,7 +403,7 @@ class TestSeriesPlots(TestPlotBase):
         _, ax = self.plt.subplots()
         ax = df.plot(secondary_y=True, ax=ax)
         s.plot(legend=True, secondary_y=True, ax=ax)
-        # both legends are dran on left ax
+        # both legends are drawn on left ax
         # left axis must be invisible and right axis must be visible
         expected = ["a (right)", "b (right)", "c (right)", "x (right)"]
         self._check_legend_labels(ax.left_ax, labels=expected)
@@ -547,7 +415,7 @@ class TestSeriesPlots(TestPlotBase):
         _, ax = self.plt.subplots()
         ax = df.plot(secondary_y=True, ax=ax)
         s.plot(ax=ax, legend=True, secondary_y=True)
-        # both legends are dran on left ax
+        # both legends are drawn on left ax
         # left axis must be invisible and right axis must be visible
         expected = ["a (right)", "b (right)", "c (right)", "x (right)"]
         self._check_legend_labels(ax.left_ax, expected)
@@ -559,7 +427,7 @@ class TestSeriesPlots(TestPlotBase):
         _, ax = self.plt.subplots()
         ax = df.plot(secondary_y=True, mark_right=False, ax=ax)
         s.plot(ax=ax, legend=True, secondary_y=True)
-        # both legends are dran on left ax
+        # both legends are drawn on left ax
         # left axis must be invisible and right axis must be visible
         expected = ["a", "b", "c", "x (right)"]
         self._check_legend_labels(ax.left_ax, expected)
@@ -567,7 +435,6 @@ class TestSeriesPlots(TestPlotBase):
         assert ax.get_yaxis().get_visible()
         tm.close()
 
-    @pytest.mark.slow
     @pytest.mark.parametrize(
         "input_logy, expected_scale", [(True, "log"), ("sym", "symlog")]
     )
@@ -583,37 +450,17 @@ class TestSeriesPlots(TestPlotBase):
         assert ax1.get_yscale() == expected_scale
         assert ax2.get_yscale() == expected_scale
 
-    @pytest.mark.slow
     def test_plot_fails_with_dupe_color_and_style(self):
-        x = Series(randn(2))
-        with pytest.raises(ValueError):
-            _, ax = self.plt.subplots()
+        x = Series(np.random.randn(2))
+        _, ax = self.plt.subplots()
+        msg = (
+            "Cannot pass 'style' string with a color symbol and 'color' keyword "
+            "argument. Please use one or the other or pass 'style' without a color "
+            "symbol"
+        )
+        with pytest.raises(ValueError, match=msg):
             x.plot(style="k--", color="k", ax=ax)
 
-    @pytest.mark.slow
-    @td.skip_if_no_scipy
-    def test_hist_kde(self):
-
-        _, ax = self.plt.subplots()
-        ax = self.ts.plot.hist(logy=True, ax=ax)
-        self._check_ax_scales(ax, yaxis="log")
-        xlabels = ax.get_xticklabels()
-        # ticks are values, thus ticklabels are blank
-        self._check_text_labels(xlabels, [""] * len(xlabels))
-        ylabels = ax.get_yticklabels()
-        self._check_text_labels(ylabels, [""] * len(ylabels))
-
-        _check_plot_works(self.ts.plot.kde)
-        _check_plot_works(self.ts.plot.density)
-        _, ax = self.plt.subplots()
-        ax = self.ts.plot.kde(logy=True, ax=ax)
-        self._check_ax_scales(ax, yaxis="log")
-        xlabels = ax.get_xticklabels()
-        self._check_text_labels(xlabels, [""] * len(xlabels))
-        ylabels = ax.get_yticklabels()
-        self._check_text_labels(ylabels, [""] * len(ylabels))
-
-    @pytest.mark.slow
     @td.skip_if_no_scipy
     def test_kde_kwargs(self):
         sample_points = np.linspace(-100, 100, 20)
@@ -627,7 +474,6 @@ class TestSeriesPlots(TestPlotBase):
         self._check_ax_scales(ax, yaxis="log")
         self._check_text_labels(ax.yaxis.get_label(), "Density")
 
-    @pytest.mark.slow
     @td.skip_if_no_scipy
     def test_kde_missing_vals(self):
         s = Series(np.random.uniform(size=50))
@@ -637,40 +483,6 @@ class TestSeriesPlots(TestPlotBase):
         # gh-14821: check if the values have any missing values
         assert any(~np.isnan(axes.lines[0].get_xdata()))
 
-    @pytest.mark.slow
-    def test_hist_kwargs(self):
-        _, ax = self.plt.subplots()
-        ax = self.ts.plot.hist(bins=5, ax=ax)
-        assert len(ax.patches) == 5
-        self._check_text_labels(ax.yaxis.get_label(), "Frequency")
-        tm.close()
-
-        _, ax = self.plt.subplots()
-        ax = self.ts.plot.hist(orientation="horizontal", ax=ax)
-        self._check_text_labels(ax.xaxis.get_label(), "Frequency")
-        tm.close()
-
-        _, ax = self.plt.subplots()
-        ax = self.ts.plot.hist(align="left", stacked=True, ax=ax)
-        tm.close()
-
-    @pytest.mark.slow
-    @td.skip_if_no_scipy
-    def test_hist_kde_color(self):
-        _, ax = self.plt.subplots()
-        ax = self.ts.plot.hist(logy=True, bins=10, color="b", ax=ax)
-        self._check_ax_scales(ax, yaxis="log")
-        assert len(ax.patches) == 10
-        self._check_colors(ax.patches, facecolors=["b"] * 10)
-
-        _, ax = self.plt.subplots()
-        ax = self.ts.plot.kde(logy=True, color="r", ax=ax)
-        self._check_ax_scales(ax, yaxis="log")
-        lines = ax.get_lines()
-        assert len(lines) == 1
-        self._check_colors(lines, ["r"])
-
-    @pytest.mark.slow
     def test_boxplot_series(self):
         _, ax = self.plt.subplots()
         ax = self.ts.plot.box(logy=True, ax=ax)
@@ -680,7 +492,6 @@ class TestSeriesPlots(TestPlotBase):
         ylabels = ax.get_yticklabels()
         self._check_text_labels(ylabels, [""] * len(ylabels))
 
-    @pytest.mark.slow
     def test_kind_both_ways(self):
         s = Series(range(3))
         kinds = (
@@ -694,7 +505,6 @@ class TestSeriesPlots(TestPlotBase):
             getattr(s.plot, kind)()
             self.plt.close()
 
-    @pytest.mark.slow
     def test_invalid_plot_data(self):
         s = Series(list("abcd"))
         _, ax = self.plt.subplots()
@@ -704,7 +514,6 @@ class TestSeriesPlots(TestPlotBase):
             with pytest.raises(TypeError, match=msg):
                 s.plot(kind=kind, ax=ax)
 
-    @pytest.mark.slow
     def test_valid_object_plot(self):
         s = Series(range(10), dtype=object)
         for kind in plotting.PlotAccessor._common_kinds:
@@ -721,15 +530,14 @@ class TestSeriesPlots(TestPlotBase):
 
     def test_invalid_kind(self):
         s = Series([1, 2])
-        with pytest.raises(ValueError):
-            s.plot(kind="aasdf")
+        with pytest.raises(ValueError, match="invalid_kind is not a valid plot kind"):
+            s.plot(kind="invalid_kind")
 
-    @pytest.mark.slow
     def test_dup_datetime_index_plot(self):
         dr1 = date_range("1/1/2009", periods=4)
         dr2 = date_range("1/2/2009", periods=4)
         index = dr1.append(dr2)
-        values = randn(index.size)
+        values = np.random.randn(index.size)
         s = Series(values, index=index)
         _check_plot_works(s.plot)
 
@@ -753,12 +561,11 @@ class TestSeriesPlots(TestPlotBase):
 
         tm.close()
 
-    @pytest.mark.slow
     def test_errorbar_plot(self):
 
         s = Series(np.arange(10), name="x")
         s_err = np.random.randn(10)
-        d_err = DataFrame(randn(10, 2), index=s.index, columns=["x", "y"])
+        d_err = DataFrame(np.random.randn(10, 2), index=s.index, columns=["x", "y"])
         # test line and bar plots
         kinds = ["line", "bar"]
         for kind in kinds:
@@ -780,7 +587,7 @@ class TestSeriesPlots(TestPlotBase):
         ix = date_range("1/1/2000", "1/1/2001", freq="M")
         ts = Series(np.arange(12), index=ix, name="x")
         ts_err = Series(np.random.randn(12), index=ix)
-        td_err = DataFrame(randn(12, 2), index=ix, columns=["x", "y"])
+        td_err = DataFrame(np.random.randn(12, 2), index=ix, columns=["x", "y"])
 
         ax = _check_plot_works(ts.plot, yerr=ts_err)
         self._check_has_errorbars(ax, xerr=0, yerr=1)
@@ -788,18 +595,17 @@ class TestSeriesPlots(TestPlotBase):
         self._check_has_errorbars(ax, xerr=0, yerr=1)
 
         # check incorrect lengths and types
-        with pytest.raises(ValueError):
+        with tm.external_error_raised(ValueError):
             s.plot(yerr=np.arange(11))
 
         s_err = ["zzz"] * 10
-        with pytest.raises(TypeError):
+        with tm.external_error_raised(TypeError):
             s.plot(yerr=s_err)
 
     def test_table(self):
         _check_plot_works(self.series.plot, table=True)
         _check_plot_works(self.series.plot, table=self.series)
 
-    @pytest.mark.slow
     def test_series_grid_settings(self):
         # Make sure plot defaults to rcParams['axes.grid'] setting, GH 9792
         self._check_grid_settings(
@@ -807,55 +613,53 @@ class TestSeriesPlots(TestPlotBase):
             plotting.PlotAccessor._series_kinds + plotting.PlotAccessor._common_kinds,
         )
 
-    @pytest.mark.slow
     def test_standard_colors(self):
-        from pandas.plotting._matplotlib.style import _get_standard_colors
+        from pandas.plotting._matplotlib.style import get_standard_colors
 
         for c in ["r", "red", "green", "#FF0000"]:
-            result = _get_standard_colors(1, color=c)
+            result = get_standard_colors(1, color=c)
             assert result == [c]
 
-            result = _get_standard_colors(1, color=[c])
+            result = get_standard_colors(1, color=[c])
             assert result == [c]
 
-            result = _get_standard_colors(3, color=c)
+            result = get_standard_colors(3, color=c)
             assert result == [c] * 3
 
-            result = _get_standard_colors(3, color=[c])
+            result = get_standard_colors(3, color=[c])
             assert result == [c] * 3
 
-    @pytest.mark.slow
     def test_standard_colors_all(self):
         import matplotlib.colors as colors
 
-        from pandas.plotting._matplotlib.style import _get_standard_colors
+        from pandas.plotting._matplotlib.style import get_standard_colors
 
         # multiple colors like mediumaquamarine
         for c in colors.cnames:
-            result = _get_standard_colors(num_colors=1, color=c)
+            result = get_standard_colors(num_colors=1, color=c)
             assert result == [c]
 
-            result = _get_standard_colors(num_colors=1, color=[c])
+            result = get_standard_colors(num_colors=1, color=[c])
             assert result == [c]
 
-            result = _get_standard_colors(num_colors=3, color=c)
+            result = get_standard_colors(num_colors=3, color=c)
             assert result == [c] * 3
 
-            result = _get_standard_colors(num_colors=3, color=[c])
+            result = get_standard_colors(num_colors=3, color=[c])
             assert result == [c] * 3
 
         # single letter colors like k
         for c in colors.ColorConverter.colors:
-            result = _get_standard_colors(num_colors=1, color=c)
+            result = get_standard_colors(num_colors=1, color=c)
             assert result == [c]
 
-            result = _get_standard_colors(num_colors=1, color=[c])
+            result = get_standard_colors(num_colors=1, color=[c])
             assert result == [c]
 
-            result = _get_standard_colors(num_colors=3, color=c)
+            result = get_standard_colors(num_colors=3, color=c)
             assert result == [c] * 3
 
-            result = _get_standard_colors(num_colors=3, color=[c])
+            result = get_standard_colors(num_colors=3, color=[c])
             assert result == [c] * 3
 
     def test_series_plot_color_kwargs(self):
@@ -896,7 +700,7 @@ class TestSeriesPlots(TestPlotBase):
 
     def test_xtick_barPlot(self):
         # GH28172
-        s = pd.Series(range(10), index=[f"P{i:02d}" for i in range(10)])
+        s = Series(range(10), index=[f"P{i:02d}" for i in range(10)])
         ax = s.plot.bar(xticks=range(0, 11, 2))
         exp = np.array(list(range(0, 11, 2)))
         tm.assert_numpy_array_equal(exp, ax.get_xticks())
@@ -942,7 +746,7 @@ class TestSeriesPlots(TestPlotBase):
 
     def test_plot_no_rows(self):
         # GH 27758
-        df = pd.Series(dtype=int)
+        df = Series(dtype=int)
         assert df.empty
         ax = df.plot()
         assert len(ax.get_lines()) == 1
@@ -951,14 +755,33 @@ class TestSeriesPlots(TestPlotBase):
         assert len(line.get_ydata()) == 0
 
     def test_plot_no_numeric_data(self):
-        df = pd.Series(["a", "b", "c"])
-        with pytest.raises(TypeError):
+        df = Series(["a", "b", "c"])
+        with pytest.raises(TypeError, match="no numeric data to plot"):
             df.plot()
 
+    @pytest.mark.parametrize(
+        "data, index",
+        [
+            ([1, 2, 3, 4], [3, 2, 1, 0]),
+            ([10, 50, 20, 30], [1910, 1920, 1980, 1950]),
+        ],
+    )
+    def test_plot_order(self, data, index):
+        # GH38865 Verify plot order of a Series
+        ser = Series(data=data, index=index)
+        ax = ser.plot(kind="bar")
+
+        expected = ser.tolist()
+        result = [
+            patch.get_bbox().ymax
+            for patch in sorted(ax.patches, key=lambda patch: patch.get_bbox().xmax)
+        ]
+        assert expected == result
+
     def test_style_single_ok(self):
-        s = pd.Series([1, 2])
+        s = Series([1, 2])
         ax = s.plot(style="s", color="C3")
-        assert ax.lines[0].get_color() == ["C3"]
+        assert ax.lines[0].get_color() == "C3"
 
     @pytest.mark.parametrize(
         "index_name, old_label, new_label",
@@ -967,7 +790,7 @@ class TestSeriesPlots(TestPlotBase):
     @pytest.mark.parametrize("kind", ["line", "area", "bar"])
     def test_xlabel_ylabel_series(self, kind, index_name, old_label, new_label):
         # GH 9093
-        ser = pd.Series([1, 2, 3, 4])
+        ser = Series([1, 2, 3, 4])
         ser.index.name = index_name
 
         # default is the ylabel is not shown and xlabel is index name
@@ -975,7 +798,20 @@ class TestSeriesPlots(TestPlotBase):
         assert ax.get_ylabel() == ""
         assert ax.get_xlabel() == old_label
 
-        # old xlabel will be overriden and assigned ylabel will be used as ylabel
+        # old xlabel will be overridden and assigned ylabel will be used as ylabel
         ax = ser.plot(kind=kind, ylabel=new_label, xlabel=new_label)
         assert ax.get_ylabel() == new_label
         assert ax.get_xlabel() == new_label
+
+    @pytest.mark.parametrize(
+        "index",
+        [
+            pd.timedelta_range(start=0, periods=2, freq="D"),
+            [pd.Timedelta(days=1), pd.Timedelta(days=2)],
+        ],
+    )
+    def test_timedelta_index(self, index):
+        # GH37454
+        xlims = (3, 1)
+        ax = Series([1, 2], index=index).plot(xlim=(xlims))
+        assert ax.get_xlim() == (3, 1)
