@@ -3,7 +3,14 @@ import pytest
 
 from pandas._libs.tslibs import IncompatibleFrequency
 
-from pandas import Series, Timestamp, date_range, isna, notna, offsets
+from pandas import (
+    Series,
+    Timestamp,
+    date_range,
+    isna,
+    notna,
+    offsets,
+)
 import pandas._testing as tm
 
 
@@ -90,7 +97,10 @@ class TestSeriesAsof:
         tm.assert_series_equal(result, expected)
 
     def test_periodindex(self):
-        from pandas import period_range, PeriodIndex
+        from pandas import (
+            PeriodIndex,
+            period_range,
+        )
 
         # array or list or dates
         N = 50
@@ -161,9 +171,6 @@ class TestSeriesAsof:
     def test_all_nans(self):
         # GH 15713
         # series is all nans
-        result = Series([np.nan]).asof([0])
-        expected = Series([np.nan])
-        tm.assert_series_equal(result, expected)
 
         # testing non-default indexes
         N = 50
